/*****************************************************
 Header file for ICQ protocol structres and constants
 (c) 1999 Jeremy Wise
 GnomeICU
******************************************************/

#ifndef __GNOMEICU_H__
#define __GNOMEICU_H__

#include "common.h"

extern GSList *Contacts;
extern Contact_Member New_Contact;
extern WORD seq_num;
extern DWORD our_ip;
extern DWORD our_port;
extern gboolean Quit;
extern DWORD Current_Status;
extern DWORD last_recv_uin;
extern gchar *passwd;
extern gchar *server;
extern DWORD remote_port;
extern DWORD set_status;
extern gchar *Away_Message;
extern gboolean Done_Login;
extern gint connecting;

extern _programs *programs;

extern gboolean search_in_progress;
extern GtkWidget *log_list;
extern GtkWidget *log_window;

extern gint autohide_time;
extern gint max_tcp_port;
extern gint min_tcp_port;

extern gboolean sound_disable;

extern BYTE chat_fg_red, chat_fg_green, chat_fg_blue;
extern BYTE chat_bg_red, chat_bg_green, chat_bg_blue;

extern GtkWidget *statusbar;
extern guint sound_pid;

extern GtkWidget *progress_indicator;
extern GtkTooltips *status_tooltip;

extern gboolean is_new_user;

extern USER_INFO_STRUCT our_user_info;

extern gchar *WindowTitle;
extern gint WindowWidth, WindowHeight;

extern gchar *configfilename;

extern gint tcp_gdk_input;
extern gint udp_gdk_input;

extern guint next_resend;

extern struct sokandlb *MainData;

extern gint Connected;

extern GdkFont *ChatFont;
extern gchar *ChatFontString;

extern DWORD our_session;

extern USER_INFO_PTR our_info;

extern GtkWidget *app;

extern gboolean been_thru_init;

extern gboolean enable_online_events;

extern gboolean webpresence;

extern _toggles *toggles;

extern GtkWidget *eyes_animated;
extern GtkWidget *eyes_still;

void create_tcp_line( void );
void ready_set( void );
void create_animator( GtkWidget *hbox_parent );
void toggle_log_window( GtkWidget *widget, gpointer data );
void init( void );
void go_url_home (void);
void go_url_updates (void);

#endif /* __GNOMEICU_H__ */
